#r "System"
#r "System.Core"
#r "System.Drawing"
#r "System.Windows.Forms"

#load "Utils.fsx"
#load "Crc.fsx"
#load "Deflate.fsx"
#load "Zip.fsx"
#load "V6Type.fsx"
#load "V6FS.fsx"

open System
open System.IO
open System.Drawing
open System.Windows.Forms

[<STAThread>] do
Application.EnableVisualStyles()
Application.SetCompatibleTextRenderingDefault(false)

let f = new Form(AutoScaleDimensions = SizeF(6.f, 12.f),
                 AutoScaleMode = AutoScaleMode.Font,
                 ClientSize = Size(292, 266),
                 Text = "V6FS")

let textBox1 = new TextBox(Dock = DockStyle.Fill,
                           Font = new Font("ＭＳ ゴシック", 9.f, FontStyle.Regular, GraphicsUnit.Point, 128uy),
                           Multiline = true,
                           ScrollBars = ScrollBars.Both,
                           Size = Size(292,  266),
                           WordWrap = false)
f.Controls.Add textBox1

let miFile        = new MenuItem(Text = "ファイル(&F)")
let miFileOpen    = new MenuItem(Text = "開く(&O)")
let miFileSaveZip = new MenuItem(Text = "&Zipで保存", Enabled = false)
let miFileSep1    = new MenuItem(Text = "-")
let miFileExit    = new MenuItem(Text = "終了(&X)")
miFile.MenuItems.AddRange [| miFileOpen; miFileSaveZip; miFileSep1; miFileExit |]

let mainMenu1 = new MainMenu()
mainMenu1.MenuItems.Add miFile |> ignore
f.Menu <- mainMenu1

let openFileDialog1 = new OpenFileDialog()
let saveFileDialog1 = new SaveFileDialog(Filter = "Zip ファイル (*.zip)|*.zip|すべてのファイル (*.*)|*.*")

let root = ref Unchecked.defaultof<V6FS.Entry>

miFileOpen.Click.Add <| fun e ->
    if openFileDialog1.ShowDialog(f) <> DialogResult.OK then () else
    let fn = openFileDialog1.FileName
    let sw = new StringWriter()
    try
        using (new FileStream(fn, FileMode.Open)) <| fun fs ->
            root := V6FS.Open(fs)
        (!root).FileSystem.Write(sw)
        let rec dir(e : V6FS.Entry) =
            sw.WriteLine()
            e.Write(sw)
            for child in e.Children do
                dir(child)
        dir(!root)
        miFileSaveZip.Enabled <- true
        let zip = Path.ChangeExtension(fn, ".zip")
        saveFileDialog1.FileName <- Path.GetFileName(zip)
    with e ->
        sw.WriteLine(e.ToString())
        miFileSaveZip.Enabled <- false
        root := Unchecked.defaultof<V6FS.Entry>
    textBox1.Text <- sw.ToString()

miFileSaveZip.Click.Add <| fun e ->
    if saveFileDialog1.ShowDialog(f) <> DialogResult.OK then () else
    let cur = Cursor.Current
    Cursor.Current <- Cursors.WaitCursor
    try
        using (new FileStream(saveFileDialog1.FileName, FileMode.Create)) <| fun fs ->
            V6FS.SaveZip(fs, !root)
    with e ->
        ignore <| MessageBox.Show(
            e.ToString(), f.Text,
            MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
    Cursor.Current <- cur

miFileExit.Click.Add <| fun e -> f.Close()

Application.Run(f)
